package net.wanji.datacenter.task;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.utils.tool.StringUtils;
import net.wanji.datacenter.cache.DataProcessServiceRegistrator;
import net.wanji.datacenter.service.dataconvert.DataProcessService;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * @author duanruiming
 * @date 2023/03/10 14:35
 */
@Component
@Slf4j
@RequiredArgsConstructor
public class DataProcessTask {

    private final DataProcessServiceRegistrator dataProcessServiceRegistor;

    @Scheduled(fixedRate = 1 * 60 * 1000)
    public void dataProcess() throws Exception {
        try {
            Map<String, DataProcessService> registor = dataProcessServiceRegistor.getDataProcessServiceRegistor();
            if (!registor.isEmpty()) {
                for (Map.Entry<String, DataProcessService> entry : registor.entrySet()) {
                    String beanName = entry.getKey();
                    DataProcessService bean = entry.getValue();
                    // 通过服务名/主题名获取不同主题数据
                    String message = bean.receive(beanName);
                    // 数据转化
                    if (StringUtils.isBlank(message)) {
                        message = "{\"eventList\":[{\"dynamic_queue_length_max\":40.975341796875,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":48,\"lane_flow_rate\":36.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.75,\"lane_saturation_flow_rate\":48,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":0.3242078320733432,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":4.335211267605633,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.01257999986410141,\"traffic_flow\":3,\"trolley_equivalent\":3,\"vehicle_length_ratio_mean\":0.012526985547440197,\"vehicle_nums_ratio_mean\":0.020196877121520705},{\"dynamic_queue_length_max\":40.0,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.06967829167842865,\"laneId\":\"\",\"lane_capacity\":276,\"lane_flow_rate\":204.0,\"lane_no_stop_rate\":0.8936170339584351,\"lane_one_stop_rate\":0.10638298094272614,\"lane_saturation\":0.739130437374115,\"lane_saturation_flow_rate\":276,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":17.12477208828104,\"light_green_start_queue_length\":9.938938453279693,\"mean_delay\":5.74468085106383,\"mean_stops_number\":0,\"mean_v\":1.8776506024096384,\"static_queue_length_max\":40.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.7083266377449036,\"traffic_flow\":17,\"trolley_equivalent\":17,\"vehicle_length_ratio_mean\":0.3361885299892225,\"vehicle_nums_ratio_mean\":0.28029531568228105},{\"dynamic_queue_length_max\":68.16592407226563,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":0,\"lane_flow_rate\":0.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.0,\"lane_saturation_flow_rate\":0,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":2.1223698196739984,\"light_green_start_queue_length\":0.4052462495606521,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":3.4737642585551347,\"static_queue_length_max\":3.681959867477417,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0,\"traffic_flow\":0,\"trolley_equivalent\":0,\"vehicle_length_ratio_mean\":0.006259700711133706,\"vehicle_nums_ratio_mean\":0.018911842165738647},{\"dynamic_queue_length_max\":61.581146240234375,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":72,\"lane_flow_rate\":48.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.6666666865348816,\"lane_saturation_flow_rate\":72,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":1.3318108032489646,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":7.212631578947371,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.008883332833647728,\"traffic_flow\":4,\"trolley_equivalent\":4,\"vehicle_length_ratio_mean\":0.003597769999430241,\"vehicle_nums_ratio_mean\":0.004687550599710195},{\"dynamic_queue_length_max\":63.37282943725586,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":264,\"lane_flow_rate\":252.0,\"lane_no_stop_rate\":0.9696969985961914,\"lane_one_stop_rate\":0.03030303120613098,\"lane_saturation\":0.9545454382896423,\"lane_saturation_flow_rate\":264,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":4.945268778965391,\"light_green_start_queue_length\":2.922568074588118,\"mean_delay\":1.3636363636363635,\"mean_stops_number\":0,\"mean_v\":3.3937572254335286,\"static_queue_length_max\":16.445341110229492,\"static_queue_length_min\":0.0,\"time_occupancy\":0.26542335748672485,\"traffic_flow\":21,\"trolley_equivalent\":21,\"vehicle_length_ratio_mean\":0.03733014619358526,\"vehicle_nums_ratio_mean\":0.029208289426470076},{\"dynamic_queue_length_max\":56.268768310546875,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":96,\"lane_flow_rate\":96.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":1.0,\"lane_saturation_flow_rate\":96,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":4.970868834133806,\"light_green_start_queue_length\":2.2785396247074523,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":1.8774834437086092,\"static_queue_length_max\":21.169273376464844,\"static_queue_length_min\":0.0,\"time_occupancy\":0.21854667365550995,\"traffic_flow\":8,\"trolley_equivalent\":8,\"vehicle_length_ratio_mean\":0.01890855935545738,\"vehicle_nums_ratio_mean\":0.016454919001741307},{\"dynamic_queue_length_max\":74.82034301757813,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":336,\"lane_flow_rate\":336.0,\"lane_no_stop_rate\":0.9259259104728699,\"lane_one_stop_rate\":0.07407407462596893,\"lane_saturation\":1.0,\"lane_saturation_flow_rate\":336,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":10.449663754167227,\"light_green_start_queue_length\":6.243474763015221,\"mean_delay\":3.888888888888889,\"mean_stops_number\":0,\"mean_v\":3.417926565874727,\"static_queue_length_max\":22.74837303161621,\"static_queue_length_min\":0.0,\"time_occupancy\":0.36901333928108215,\"traffic_flow\":24,\"trolley_equivalent\":28,\"vehicle_length_ratio_mean\":0.09141811475446049,\"vehicle_nums_ratio_mean\":0.08030259135657844},{\"dynamic_queue_length_max\":470.63189697265625,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":180,\"lane_flow_rate\":180.0,\"lane_no_stop_rate\":0.9555555582046509,\"lane_one_stop_rate\":0.04444444552063942,\"lane_saturation\":1.0,\"lane_saturation_flow_rate\":180,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":16.329852498810865,\"light_green_start_queue_length\":11.722974982754938,\"mean_delay\":2.5,\"mean_stops_number\":0,\"mean_v\":1.8117421602787458,\"static_queue_length_max\":46.890625,\"static_queue_length_min\":0.0,\"time_occupancy\":0.6800199747085571,\"traffic_flow\":11,\"trolley_equivalent\":15,\"vehicle_length_ratio_mean\":0.06779336408589944,\"vehicle_nums_ratio_mean\":0.0582711032875646},{\"dynamic_queue_length_max\":23.018892288208008,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.012964434921741486,\"laneId\":\"\",\"lane_capacity\":72,\"lane_flow_rate\":36.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.5,\"lane_saturation_flow_rate\":72,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":0.6141861389423239,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":4.541960784313726,\"static_queue_length_max\":17.1435604095459,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0071033332496881485,\"traffic_flow\":3,\"trolley_equivalent\":3,\"vehicle_length_ratio_mean\":0.002242794503171429,\"vehicle_nums_ratio_mean\":0.00287633546288533},{\"dynamic_queue_length_max\":114.65453338623047,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":0,\"lane_flow_rate\":0.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.0,\"lane_saturation_flow_rate\":0,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":14.023659467697144,\"light_green_start_queue_length\":0.0992967753574766,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":3.6110457516339856,\"static_queue_length_max\":4.859949588775635,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0,\"traffic_flow\":0,\"trolley_equivalent\":0,\"vehicle_length_ratio_mean\":0.0012805742346469846,\"vehicle_nums_ratio_mean\":0.0027028174197727415},{\"dynamic_queue_length_max\":372.0594177246094,\"dynamic_queue_length_min\":2.3399829864501953,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":444,\"lane_flow_rate\":384.0,\"lane_no_stop_rate\":0.9885714054107666,\"lane_one_stop_rate\":0.011428571306169033,\"lane_saturation\":0.8648648858070374,\"lane_saturation_flow_rate\":444,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":154.56714787976495,\"light_green_start_queue_length\":13.386706187807281,\"mean_delay\":0.9428571428571428,\"mean_stops_number\":0,\"mean_v\":4.7758273381294964,\"static_queue_length_max\":43.37940979003906,\"static_queue_length_min\":0.0,\"time_occupancy\":0.036986663937568665,\"traffic_flow\":29,\"trolley_equivalent\":32,\"vehicle_length_ratio_mean\":0.07698311852651615,\"vehicle_nums_ratio_mean\":0.05800237682902805},{\"dynamic_queue_length_max\":371.6435241699219,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":96,\"lane_flow_rate\":72.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.75,\"lane_saturation_flow_rate\":96,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":149.71256256103516,\"light_green_start_queue_length\":12.456866034146014,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":9.356060606060607,\"static_queue_length_max\":368.05401611328125,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0038433328736573458,\"traffic_flow\":6,\"trolley_equivalent\":6,\"vehicle_length_ratio_mean\":0.013071173843431356,\"vehicle_nums_ratio_mean\":0.014736083131637588},{\"dynamic_queue_length_max\":370.0,\"dynamic_queue_length_min\":2.965820550918579,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":492,\"lane_flow_rate\":432.0,\"lane_no_stop_rate\":0.9834254384040833,\"lane_one_stop_rate\":0.016574585810303688,\"lane_saturation\":0.8780487775802612,\"lane_saturation_flow_rate\":492,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":188.10887777394262,\"light_green_start_queue_length\":15.665639088071625,\"mean_delay\":1.2430939226519337,\"mean_stops_number\":0,\"mean_v\":5.717452107279695,\"static_queue_length_max\":85.60419464111328,\"static_queue_length_min\":0.0,\"time_occupancy\":0.4382700026035309,\"traffic_flow\":36,\"trolley_equivalent\":36,\"vehicle_length_ratio_mean\":0.09328616546556728,\"vehicle_nums_ratio_mean\":0.07687118187298883},{\"dynamic_queue_length_max\":370.0,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":408,\"lane_flow_rate\":336.0,\"lane_no_stop_rate\":0.9520000219345093,\"lane_one_stop_rate\":0.04800000041723251,\"lane_saturation\":0.8235294222831726,\"lane_saturation_flow_rate\":408,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":107.36373444261223,\"light_green_start_queue_length\":8.63355828975809,\"mean_delay\":3.36,\"mean_stops_number\":0,\"mean_v\":4.588161925601749,\"static_queue_length_max\":81.62080383300781,\"static_queue_length_min\":0.0,\"time_occupancy\":0.46894001960754395,\"traffic_flow\":28,\"trolley_equivalent\":28,\"vehicle_length_ratio_mean\":0.05922727869761613,\"vehicle_nums_ratio_mean\":0.04411490205599492},{\"dynamic_queue_length_max\":75.41883850097656,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":180,\"lane_flow_rate\":168.0,\"lane_no_stop_rate\":0.7727272510528564,\"lane_one_stop_rate\":0.22727273404598236,\"lane_saturation\":0.9333333373069763,\"lane_saturation_flow_rate\":180,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":22.843779037738667,\"light_green_start_queue_length\":11.869044271008722,\"mean_delay\":16.363636363636363,\"mean_stops_number\":0,\"mean_v\":4.588436830835113,\"static_queue_length_max\":28.49137306213379,\"static_queue_length_min\":0.0,\"time_occupancy\":0.8092133402824402,\"traffic_flow\":12,\"trolley_equivalent\":14,\"vehicle_length_ratio_mean\":0.1949437555578175,\"vehicle_nums_ratio_mean\":0.14591537143096822},{\"dynamic_queue_length_max\":46.60673904418945,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.13525336980819702,\"laneId\":\"\",\"lane_capacity\":204,\"lane_flow_rate\":192.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.9411764740943909,\"lane_saturation_flow_rate\":204,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":15.36799144744873,\"light_green_start_queue_length\":8.714151109967913,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":3.4473863636363635,\"static_queue_length_max\":42.199012756347656,\"static_queue_length_min\":0.0,\"time_occupancy\":0.33947670459747314,\"traffic_flow\":16,\"trolley_equivalent\":16,\"vehicle_length_ratio_mean\":0.049264598236964906,\"vehicle_nums_ratio_mean\":0.04934657162253903},{\"dynamic_queue_length_max\":44.676570892333984,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.060385480523109436,\"laneId\":\"\",\"lane_capacity\":48,\"lane_flow_rate\":48.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":1.0,\"lane_saturation_flow_rate\":48,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":0.0,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":4.017500000000001,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0068066660314798355,\"traffic_flow\":4,\"trolley_equivalent\":4,\"vehicle_length_ratio_mean\":0.0019217923015497692,\"vehicle_nums_ratio_mean\":0.0013577732518669382},{\"dynamic_queue_length_max\":50.045387268066406,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.14726360142230988,\"laneId\":\"\",\"lane_capacity\":336,\"lane_flow_rate\":336.0,\"lane_no_stop_rate\":0.9534883499145508,\"lane_one_stop_rate\":0.04651162773370743,\"lane_saturation\":1.0,\"lane_saturation_flow_rate\":336,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":14.72541080202375,\"light_green_start_queue_length\":6.800526142120361,\"mean_delay\":3.488372093023256,\"mean_stops_number\":0,\"mean_v\":2.981413612565444,\"static_queue_length_max\":50.019309997558594,\"static_queue_length_min\":0.0,\"time_occupancy\":0.5300833582878113,\"traffic_flow\":26,\"trolley_equivalent\":28,\"vehicle_length_ratio_mean\":0.07812055642542715,\"vehicle_nums_ratio_mean\":0.08565286695906603},{\"dynamic_queue_length_max\":29.523109436035156,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":84,\"lane_flow_rate\":72.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.8571428656578064,\"lane_saturation_flow_rate\":84,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":0.0,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":4.469166666666671,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.01454333309084177,\"traffic_flow\":5,\"trolley_equivalent\":6,\"vehicle_length_ratio_mean\":0.002055284612067929,\"vehicle_nums_ratio_mean\":0.0017396469789545145},{\"dynamic_queue_length_max\":48.40139389038086,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.06887155026197433,\"laneId\":\"\",\"lane_capacity\":108,\"lane_flow_rate\":108.0,\"lane_no_stop_rate\":0.9285714030265808,\"lane_one_stop_rate\":0.0714285746216774,\"lane_saturation\":1.0,\"lane_saturation_flow_rate\":108,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":17.13508483341762,\"light_green_start_queue_length\":17.13508483341762,\"mean_delay\":2.142857142857143,\"mean_stops_number\":0,\"mean_v\":1.7502366863905314,\"static_queue_length_max\":48.40139389038086,\"static_queue_length_min\":0.0,\"time_occupancy\":0.2147066742181778,\"traffic_flow\":9,\"trolley_equivalent\":9,\"vehicle_length_ratio_mean\":0.08763728947969861,\"vehicle_nums_ratio_mean\":0.08780974202308214},{\"dynamic_queue_length_max\":371.0,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":828,\"lane_flow_rate\":696.0,\"lane_no_stop_rate\":0.9490445852279663,\"lane_one_stop_rate\":0.05095541477203369,\"lane_saturation\":0.8405796885490417,\"lane_saturation_flow_rate\":828,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":101.03698022024972,\"light_green_start_queue_length\":24.407301357814244,\"mean_delay\":4.012738853503185,\"mean_stops_number\":0,\"mean_v\":4.42488933601609,\"static_queue_length_max\":52.10312271118164,\"static_queue_length_min\":0.0,\"time_occupancy\":0.6676632761955261,\"traffic_flow\":56,\"trolley_equivalent\":58,\"vehicle_length_ratio_mean\":0.1073623936127325,\"vehicle_nums_ratio_mean\":0.10431093066103772},{\"dynamic_queue_length_max\":372.4347839355469,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":108,\"lane_flow_rate\":60.0,\"lane_no_stop_rate\":0.9909090995788574,\"lane_one_stop_rate\":0.00909090880304575,\"lane_saturation\":0.5555555820465088,\"lane_saturation_flow_rate\":108,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":183.26575967243738,\"light_green_start_queue_length\":1.7458618027823312,\"mean_delay\":0.5454545454545454,\"mean_stops_number\":0,\"mean_v\":2.369907407407407,\"static_queue_length_max\":15.441865921020508,\"static_queue_length_min\":0.0,\"time_occupancy\":0.260696679353714,\"traffic_flow\":5,\"trolley_equivalent\":5,\"vehicle_length_ratio_mean\":0.03587172349544403,\"vehicle_nums_ratio_mean\":0.03281992581373906},{\"dynamic_queue_length_max\":373.38916015625,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":60,\"lane_flow_rate\":60.0,\"lane_no_stop_rate\":0.9918032884597778,\"lane_one_stop_rate\":0.008196720853447914,\"lane_saturation\":1.0,\"lane_saturation_flow_rate\":60,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":208.2078195299421,\"light_green_start_queue_length\":0.4642688206263951,\"mean_delay\":0.6147540983606558,\"mean_stops_number\":0,\"mean_v\":2.714743202416921,\"static_queue_length_max\":7.421406269073486,\"static_queue_length_min\":0.0,\"time_occupancy\":0.22264666855335236,\"traffic_flow\":5,\"trolley_equivalent\":5,\"vehicle_length_ratio_mean\":0.047669618556627505,\"vehicle_nums_ratio_mean\":0.038675322940918314},{\"dynamic_queue_length_max\":51.19540786743164,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.12543940544128418,\"laneId\":\"\",\"lane_capacity\":300,\"lane_flow_rate\":276.0,\"lane_no_stop_rate\":0.9047619104385376,\"lane_one_stop_rate\":0.095238097012043,\"lane_saturation\":0.9200000166893005,\"lane_saturation_flow_rate\":300,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":23.933147975376674,\"light_green_start_queue_length\":18.824801445007324,\"mean_delay\":11.071428571428571,\"mean_stops_number\":0,\"mean_v\":3.4368482490272374,\"static_queue_length_max\":51.19540786743164,\"static_queue_length_min\":0.0,\"time_occupancy\":0.7569065690040588,\"traffic_flow\":19,\"trolley_equivalent\":23,\"vehicle_length_ratio_mean\":0.22347544479637185,\"vehicle_nums_ratio_mean\":0.17155088182698078},{\"dynamic_queue_length_max\":48.06354904174805,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.25814419984817505,\"laneId\":\"\",\"lane_capacity\":456,\"lane_flow_rate\":420.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.9210526347160339,\"lane_saturation_flow_rate\":456,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":6.743759768349784,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":9.33344947735192,\"static_queue_length_max\":21.375097274780273,\"static_queue_length_min\":0.0,\"time_occupancy\":0.08263000845909119,\"traffic_flow\":35,\"trolley_equivalent\":35,\"vehicle_length_ratio_mean\":0.032610454184976226,\"vehicle_nums_ratio_mean\":0.029173267185839763},{\"dynamic_queue_length_max\":52.07501983642578,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.07083287835121155,\"laneId\":\"\",\"lane_capacity\":204,\"lane_flow_rate\":180.0,\"lane_no_stop_rate\":0.8285714387893677,\"lane_one_stop_rate\":0.17142857611179352,\"lane_saturation\":0.8823529481887817,\"lane_saturation_flow_rate\":204,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":28.14895793369838,\"light_green_start_queue_length\":27.185110364641464,\"mean_delay\":12.428571428571429,\"mean_stops_number\":0,\"mean_v\":2.3490223463687148,\"static_queue_length_max\":51.60746765136719,\"static_queue_length_min\":0.0,\"time_occupancy\":0.5188466310501099,\"traffic_flow\":15,\"trolley_equivalent\":15,\"vehicle_length_ratio_mean\":0.23345167850677204,\"vehicle_nums_ratio_mean\":0.16815644997574808},{\"dynamic_queue_length_max\":48.34062576293945,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.08141857385635376,\"laneId\":\"\",\"lane_capacity\":336,\"lane_flow_rate\":180.0,\"lane_no_stop_rate\":0.9117646813392639,\"lane_one_stop_rate\":0.0882352963089943,\"lane_saturation\":0.5357142686843872,\"lane_saturation_flow_rate\":336,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":20.943053245544434,\"light_green_start_queue_length\":15.544171469552177,\"mean_delay\":9.264705882352942,\"mean_stops_number\":0,\"mean_v\":3.3683863080684575,\"static_queue_length_max\":45.82487106323242,\"static_queue_length_min\":0.0,\"time_occupancy\":0.648930013179779,\"traffic_flow\":15,\"trolley_equivalent\":15,\"vehicle_length_ratio_mean\":0.17561335737380096,\"vehicle_nums_ratio_mean\":0.13609791253437337},{\"dynamic_queue_length_max\":42.26611328125,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":0,\"lane_flow_rate\":0.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.0,\"lane_saturation_flow_rate\":0,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":4.69802736384528,\"light_green_start_queue_length\":0.11607186283384051,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":7.513181818181817,\"static_queue_length_max\":3.347986936569214,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0,\"traffic_flow\":0,\"trolley_equivalent\":0,\"vehicle_length_ratio_mean\":0.0040865438365619644,\"vehicle_nums_ratio_mean\":0.014162329443492052},{\"dynamic_queue_length_max\":48.721282958984375,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.1409478783607483,\"laneId\":\"\",\"lane_capacity\":348,\"lane_flow_rate\":204.0,\"lane_no_stop_rate\":0.875,\"lane_one_stop_rate\":0.125,\"lane_saturation\":0.5862069129943848,\"lane_saturation_flow_rate\":348,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":26.508986609322683,\"light_green_start_queue_length\":16.698043823242188,\"mean_delay\":13.125,\"mean_stops_number\":0,\"mean_v\":2.713824228028499,\"static_queue_length_max\":46.516483306884766,\"static_queue_length_min\":0.0,\"time_occupancy\":0.6088699698448181,\"traffic_flow\":17,\"trolley_equivalent\":17,\"vehicle_length_ratio_mean\":0.23827141966830082,\"vehicle_nums_ratio_mean\":0.15022252876379824},{\"dynamic_queue_length_max\":0.0,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":0,\"lane_flow_rate\":0.0,\"lane_no_stop_rate\":0.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.0,\"lane_saturation_flow_rate\":0,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":0.0,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":0.0,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0,\"traffic_flow\":0,\"trolley_equivalent\":0,\"vehicle_length_ratio_mean\":0.0,\"vehicle_nums_ratio_mean\":0.0},{\"dynamic_queue_length_max\":0.0,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":0,\"lane_flow_rate\":0.0,\"lane_no_stop_rate\":0.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.0,\"lane_saturation_flow_rate\":0,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":0.0,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":0.0,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0,\"traffic_flow\":0,\"trolley_equivalent\":0,\"vehicle_length_ratio_mean\":0.0,\"vehicle_nums_ratio_mean\":0.0},{\"dynamic_queue_length_max\":59.1076774597168,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":0,\"lane_flow_rate\":0.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.0,\"lane_saturation_flow_rate\":0,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":2.1744209017072404,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":0.0,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0,\"traffic_flow\":0,\"trolley_equivalent\":0,\"vehicle_length_ratio_mean\":0.006782431415935317,\"vehicle_nums_ratio_mean\":0.005984921610262308},{\"dynamic_queue_length_max\":10.900229454040527,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":24,\"lane_flow_rate\":24.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":1.0,\"lane_saturation_flow_rate\":24,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":0.0,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":7.6599999999999975,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.003563334234058857,\"traffic_flow\":2,\"trolley_equivalent\":2,\"vehicle_length_ratio_mean\":0.0002124606500817899,\"vehicle_nums_ratio_mean\":0.0002143852518920743},{\"dynamic_queue_length_max\":0.0,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":0,\"lane_flow_rate\":0.0,\"lane_no_stop_rate\":0.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":0.0,\"lane_saturation_flow_rate\":0,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":0.0,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":0.0,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0,\"traffic_flow\":0,\"trolley_equivalent\":0,\"vehicle_length_ratio_mean\":0.0,\"vehicle_nums_ratio_mean\":0.0},{\"dynamic_queue_length_max\":25.074373245239258,\"dynamic_queue_length_min\":0.0,\"green_light_efficiency\":0.0,\"laneId\":\"\",\"lane_capacity\":24,\"lane_flow_rate\":24.0,\"lane_no_stop_rate\":1.0,\"lane_one_stop_rate\":0.0,\"lane_saturation\":1.0,\"lane_saturation_flow_rate\":24,\"lane_three_stop_rate\":0.0,\"lane_two_stop_rate\":0.0,\"light_green_finish_queue_length\":0.0,\"light_green_start_queue_length\":0.0,\"mean_delay\":0.0,\"mean_stops_number\":0,\"mean_v\":7.664999999999999,\"static_queue_length_max\":0.0,\"static_queue_length_min\":0.0,\"time_occupancy\":0.0022033341228961945,\"traffic_flow\":2,\"trolley_equivalent\":2,\"vehicle_length_ratio_mean\":0.00029760406802118187,\"vehicle_nums_ratio_mean\":0.0003037124401804386}],\"laneNum\":35,\"orgCode\":\"040001\",\"timeStamp\":\"2023-03-10 17:03:14:710\"}";
                    }
                    Object convert = bean.convert(message);
                    // 本地保存
                    bean.save(convert);
                    // 发送
                    bean.send(beanName, convert);
                }
            }
        } catch (Exception e) {
            log.error("数据加工处理失败");
        }
    }

}
